@@ -8,9 +8,9 @@ extern "C" {
 #endif
 
 #define MENU_DECLARE(widget)                                                                       \
-    void widget##_add(widget *, const char *name, int shortcut, Fl_Callback *, void *, int);       \
-    void widget##_insert(widget *, int index, const char *name, int shortcut, Fl_Callback *,       \
-                         void *, int);                                                             \
+    int widget##_add(widget *, const char *name, int shortcut, Fl_Callback *, void *, int);        \
+    int widget##_insert(widget *, int index, const char *name, int shortcut, Fl_Callback *,        \
+                        void *, int);                                                              \
     Fl_Menu_Item *widget##_get_item(widget *, const char *name);                                   \
     int widget##_set_item(widget *, Fl_Menu_Item *item);                                           \
     int widget##_text_font(widget *);                                                              \
@@ -122,6 +122,8 @@ int Fl_Menu_Item_measure(const Fl_Menu_Item *self, int *hp, const void *m);
 
 void Fl_Menu_Item_image(Fl_Menu_Item *self, void *image);
 
+void Fl_Menu_Item_add_image(Fl_Menu_Item *self, void *image, int on_left);
+
 #ifdef __cplusplus
 }
 #endif
